"""Represent incremental, relative timeouts."""

__author__ = 'Jeffrey Knockel'
__copyright__ = 'Copyright 2013 Jeffrey Knockel'
__license__ = 'GPL v2'

# XXX: should use a monotonic timer, but python 2.7 doesn't have one
from time import time

class Timeout(object):
    """A representation of a relative timeout."""
    def __init__(self, delta=0.0):
        """Create Timeout object with timeout 'delta' seconds in the future."""
        self.time = time() + delta
    def timeout(self, delta=0.0):
        """Return time until next timeout, optionally adding 'delta' time until
        next timeout.

        If the timeout has already occurred, return 0.0.
        """
        self.add_time(delta)
        return max(0.0, self.time - time())
    def add_time(self, delta):
        """Add 'delta' time until next timeout."""
        self.time += delta
